@@ -3,14 +3,21 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.21';
+our $VERSION = '1.22';
 
 use Carp;
+use Exporter;
 use Fcntl qw(:flock);
 use File::Find::Rule;
 use File::Temp;
 use POSIX qw(uname);
 
+our @ISA = qw(Exporter);
+our @EXPORT_OK = qw(
+    recsep
+    platform_recsep
+);
+
 sub new {
     return bless {}, shift;
 }
@@ -35,8 +42,9 @@ sub read {
     }
 
     $self->recsep($file);
+    $self->{files}{$file}{is_read} = 1;
     $self->{files}{$file}{recsep} = $self->{recsep};
-    $self->{is_read} = 1;
+    $self->{reads}{count} = keys %{ $self->{files} };
 
     my $fh;
 
@@ -45,7 +53,7 @@ sub read {
         return $fh;
     }
     else {
-        $fh = $self->_open($file);
+        $fh = $self->_binmode_handle($file);
         my @contents = <$fh>;
         close $fh or confess "read() can't close file $file!: $!";
 
@@ -66,8 +74,10 @@ sub write {
         confess "write() requires a file to be passed in!";
     }
 
-    if (keys %{ $self->{files} } > 1 && ! $p{file}){
-        confess "if calling write() with more than one read() open, you must " .
+    my $reads_count = $self->{reads}{count} || 0;
+
+    if ($reads_count > 1 && ! $p{file}){
+        confess "\nif calling write() with more than one read() open, you must " .
                 "send in a file name with the 'file' parameter so we know " .
                 "which file to write. You currently have the following files " .
                 "open: " . join(' ', keys %{ $self->{files} }) . "\n";
@@ -76,15 +86,15 @@ sub write {
         confess "write() requires 'contents' param sent in";
     }
 
-    if (! $self->{is_read}){
-        $self->recsep($self->{file});
-    }
-
     my $file = $self->{file}; # needed for cleanup of open file list
 
+    if (! $self->{files}{$file}{is_read}){
+        $self->{files}{$file}{recsep} = $self->recsep($file);
+    }
+
     $self->{file} = $self->{copy} if $self->{copy};
 
-    my $wfh = $self->_open($self->{file}, 'w');
+    my $wfh = $self->_binmode_handle($self->{file}, 'w');
 
     # certain FreeBSD versions on amd64 don't work
     # with flock()
@@ -97,12 +107,23 @@ sub write {
 
     my $recsep = defined $self->{custom_recsep}
         ? $self->{custom_recsep}
-        : $self->{recsep};
+        : $self->{files}{$file}{recsep};
 
     my $contents = $self->{contents};
 
-    if (ref($contents) eq 'GLOB' || ref($contents) eq 'File::Temp'){
-        seek $contents, 0, 0;
+    if (ref($contents) eq 'GLOB' || ref($contents) eq 'File::Temp') {
+        {
+            my $warn;
+            local $SIG{__WARN__} = sub { $warn = shift; };
+
+            seek $contents, 0, 0;
+
+            if ($warn) {
+                confess "\nthe file handle you're passing into write() as ".
+                    "the contents param has already been closed\n";
+            }
+
+        };
 
         while (<$contents>){
             $_ = $self->_strip_ends($_);
@@ -118,8 +139,8 @@ sub write {
     }
 
     close $wfh;
-    $self->{is_read} = 0;
     delete $self->{files}{$file}; # cleanup open list
+    $self->{reads}{count} = 0 if keys %{ $self->{files} } == 0;
 
     return 1;
 }
@@ -227,13 +248,16 @@ sub dir {
     return @files;
 }
 sub recsep {
-    my $self = shift;
+    my $self = ref $_[0] eq __PACKAGE__
+        ? shift
+        : __PACKAGE__->new;
+
     my $file = shift;
-    my $want = shift if @_;
+    my $want = shift;
 
     my $fh;
     eval {
-        $fh = $self->_open($file);
+        $fh = $self->_binmode_handle($file);
     };
 
     if ($@ || ! $fh){
@@ -263,14 +287,16 @@ sub recsep {
         : $self->{recsep};
 }
 sub platform_recsep {
+    my $self = ref $_[0] eq __PACKAGE__
+        ? shift
+        : __PACKAGE__->new;
 
-    my $self = shift;
-    my $want = shift if @_;
+    my $want = shift;
 
     my $file = $self->_temp_filename;
 
     # for platform_recsep(), we need the file open in ASCII mode,
-    # so we can't use _open() or File::Temp
+    # so we can't use _binmode_handle() or File::Temp
 
     open my $wfh, '>', $file
       or confess
@@ -281,7 +307,7 @@ sub platform_recsep {
     close $wfh
       or confess "platform_recsep() can't close write temp file $file: $!";
 
-    my $fh = $self->_open($file);
+    my $fh = $self->_binmode_handle($file);
 
     my $recsep_regex = $self->_recsep_regex;
 
@@ -297,10 +323,14 @@ sub platform_recsep {
         : $self->{platform_recsep};
 }
 sub tempfile {
+    # returns a temporary file handle in write mode
+
     my $wfh = File::Temp->new(UNLINK => 1);
     return $wfh;
 }
 sub _config {
+    # configures self with incoming params
+
     my $self = shift;
     my %p = @_;
 
@@ -330,7 +360,7 @@ sub _handle {
 
     if ($self->recsep($file, 'hex') ne $self->platform_recsep('hex')){
         
-        $fh = $self->_open($file);
+        $fh = $self->_binmode_handle($file);
         my $temp_wfh = $self->tempfile;
         binmode $temp_wfh, ':raw';
 
@@ -344,16 +374,16 @@ sub _handle {
         close $fh or confess "can't close file $file: $!";
         close $temp_wfh or confess "can't close file $temp_filename: $!";
 
-        my $ret_fh = $self->_open($temp_filename);
+        my $ret_fh = $self->_binmode_handle($temp_filename);
         
         return $ret_fh;
     }
     else {
-        $fh = $self->_open($file);
+        $fh = $self->_binmode_handle($file);
         return $fh;
     }
 }
-sub _open {
+sub _binmode_handle {
     # returns a handle opened with binmode :raw
 
     my $self = shift;
@@ -364,11 +394,11 @@ sub _open {
 
     if ($mode =~ /^w/){
         open $fh, '>', $file
-          or confess "_open() can't open file $file for writing!: $!";
+          or confess "_binmode_handle() can't open file $file for writing!: $!";
     }
     else {
         open $fh, '<', $file
-          or confess "_open() can't open file $file for reading!: $!";
+          or confess "_binmode_handle() can't open file $file for reading!: $!";
     }
 
     binmode $fh, ':raw';
@@ -376,27 +406,26 @@ sub _open {
     return $fh;
 }
 sub _convert_recsep {
-    # converts recsep to either hex or OS name
+    # converts recsep to either hex or OS name (ie. type)
 
     my ($self, $sep, $want) = @_;
 
-    if ($want eq 'hex'){
-        $sep = unpack "H*", $sep;
-        $sep =~ s/0/\\0/g;
-        return $sep;
-    }
-    elsif ($want eq 'type'){
-        my $hex_sep = $self->_convert_recsep($sep, 'hex');
-        return 'nix' if $hex_sep =~ /^\\0a$/;
-        return 'win' if $hex_sep =~ /^\\0d\\0a$/;
-        return 'mac' if $hex_sep =~ /^\\0d$/;
-        return 'unknown';
-    }
+    $sep = unpack "H*", $sep;
+    $sep =~ s/0/\\0/g;
+
+    return $sep if $want eq 'hex';
+
+    my %seps = (
+        '\0a'    => 'nix',
+        '\0d\0a' => 'win',
+        '\0d'    => 'mac',
+    );
+
+    return $seps{$sep} || 'unknown';
 }
 sub _recsep_regex {
     # returns a regex object representing all recseps
-    my $re = qr/([\n\x{0B}\f\r\x{85}]{1,2})/;
-    return $re;
+    return qr/([\n\x{0B}\f\r\x{85}]{1,2})/;
 }
 sub _platform_replace {
     # replace recseps in a string with the platform recsep
@@ -415,7 +444,7 @@ sub _strip_ends {
     return $str;
 }
 sub _temp_filename {
-    shift;
+    # return the name of a temporary file
 
     my $temp_fh = File::Temp->new(UNLINK => 1);
     my $filename = $temp_fh->filename;
@@ -514,6 +543,14 @@ storage between multpile platforms are a good use case. This module affords you
 the ability to not have to check each file, and is very useful in looping over
 a directory where various files may have been written by different platforms.
 
+=head1 EXPORT
+
+None by default. See L<EXPORT_OK>
+
+=head1 EXPORT_OK
+
+C<recsep()>, C<platform_recsep()>
+
 =head1 METHODS
 
 =head2 C<new>
@@ -655,6 +692,9 @@ sent in, the record separator will be returned in hex form (eg: "\0d\0a" for
 Windows). If 'type' is sent in, we'll return a short-form of the line-ending
 type (eg: win, nix, mac, etc).
 
+Note that this method can be imported into your namespace on demand if you
+don't need the object functionality of the module.
+
 =head2 C<platform_recsep($want)>
 
 Returns the the current platform's (OS) record separator in string form.
@@ -664,6 +704,9 @@ sent in, the record separator will be returned in hex form (eg: "\0d\0a" for
 Windows). If 'type' is sent in, we'll return a short-from of the line-ending
 type (eg: win, nix, mac, etc).
 
+Note that this method can be imported into your namespace on demand if you
+don't need the object functionality of the module.
+
 =head2 C<tempfile>
 
 Returns a file handle in write mode to an empty temp file.
